@@ -23,13 +23,13 @@
 #include <uuid/uuid.h>
 #include "kerncompat.h"
 #include "kernel-lib/radix-tree.h"
-#include "ctree.h"
-#include "disk-io.h"
-#include "print-tree.h"
+#include "kernel-shared/ctree.h"
+#include "kernel-shared/disk-io.h"
+#include "kernel-shared/print-tree.h"
 #include "common/utils.h"
 #include "kernel-shared/ulist.h"
 #include "common/rbtree-utils.h"
-#include "transaction.h"
+#include "kernel-shared/transaction.h"
 #include "repair.h"
 
 #include "qgroup-verify.h"
