@@ -37,15 +37,17 @@
 #include <stdarg.h>
 #include <limits.h>
 
-#include "ctree.h"
+#include "kernel-shared/ctree.h"
 #include "ioctl.h"
 #include "common/utils.h"
-#include "volumes.h"
-#include "disk-io.h"
+#include "kernel-shared/volumes.h"
+#include "kernel-shared/disk-io.h"
 
 #include "cmds/commands.h"
 #include "common/help.h"
 
+static unsigned unit_mode = UNITS_DEFAULT;
+
 static const char * const scrub_cmd_group_usage[] = {
 	"btrfs scrub <command> [options] <path>|<device>",
 	NULL
@@ -134,7 +136,8 @@ static void print_scrub_full(struct btrfs_scrub_progress *sp)
 		printf(" %s=%llu", desc, test);	\
 } while (0)
 
-static void print_scrub_summary(struct btrfs_scrub_progress *p, struct scrub_stats *s, u64 bytes_total)
+static void print_scrub_summary(struct btrfs_scrub_progress *p, struct scrub_stats *s,
+		u64 bytes_total)
 {
 	u64 err_cnt;
 	u64 err_cnt2;
@@ -164,10 +167,7 @@ static void print_scrub_summary(struct btrfs_scrub_progress *p, struct scrub_sta
 		char t[4096];
 		struct tm tm;
 
-		if (s->t_resumed)
-			sec_eta = s->t_resumed;
-		else
-			sec_eta = s->t_start;
+		sec_eta = time(NULL);
 		sec_eta += sec_left;
 		localtime_r(&sec_eta, &tm);
 		t[sizeof(t) - 1] = '\0';
@@ -176,12 +176,25 @@ static void print_scrub_summary(struct btrfs_scrub_progress *p, struct scrub_sta
 		printf("Time left:        %llu:%02llu:%02llu\n",
 			sec_left / 3600, (sec_left / 60) % 60, sec_left % 60);
 		printf("ETA:              %s\n", t);
-		printf("Total to scrub:   %s\n", pretty_size(bytes_total));
-		printf("Bytes scrubbed:   %s\n", pretty_size(bytes_scrubbed));
-		printf("Rate:             %s/s\n", pretty_size(bytes_per_sec));
+		printf("Total to scrub:   %s\n",
+			pretty_size_mode(bytes_total, unit_mode));
+		printf("Bytes scrubbed:   %s  (%.2f%%)\n",
+			pretty_size_mode(bytes_scrubbed, unit_mode),
+			100.0 * bytes_scrubbed / bytes_total);
 	} else {
-		printf("Total to scrub:   %s\n", pretty_size(bytes_total));
-		printf("Rate:             %s/s\n", pretty_size(bytes_per_sec));
+		printf("Total to scrub:   %s\n",
+			pretty_size_mode(bytes_total, unit_mode));
+	}
+	/*
+	 * Rate and size units are disproportionate so they are affected only
+	 * by --raw, otherwise it's human readable
+	 */
+	if (unit_mode == UNITS_RAW) {
+		printf("Rate:             %s/s\n",
+			pretty_size_mode(bytes_per_sec, UNITS_RAW));
+	} else {
+		printf("Rate:             %s/s\n",
+			pretty_size(bytes_per_sec));
 	}
 
 	printf("Error summary:   ");
@@ -274,7 +287,7 @@ static void _print_scrub_ss(struct scrub_stats *ss)
 		localtime_r(&ss->t_resumed, &tm);
 		strftime(t, sizeof(t), "%c", &tm);
 		t[sizeof(t) - 1] = '\0';
-		printf("Scrub resumed:   %s\n", t);
+		printf("Scrub resumed:    %s\n", t);
 	} else {
 		localtime_r(&ss->t_start, &tm);
 		strftime(t, sizeof(t), "%c", &tm);
@@ -297,7 +310,7 @@ static void print_scrub_dev(struct btrfs_ioctl_dev_info_args *di,
 				struct btrfs_scrub_progress *p, int raw,
 				const char *append, struct scrub_stats *ss)
 {
-	printf("scrub device %s (id %llu) %s\n", di->path, di->devid,
+	printf("\nScrub device %s (id %llu) %s\n", di->path, di->devid,
 	       append ? append : "");
 
 	_print_scrub_ss(ss);
@@ -1144,7 +1157,7 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 	int do_background = 1;
 	int do_wait = 0;
 	int do_print = 0;
-	int do_quiet = 0;
+	int do_quiet = !bconf.verbose; /*Read the global quiet option if set*/
 	int do_record = 1;
 	int readonly = 0;
 	int do_stats_per_dev = 0;
@@ -1187,7 +1200,8 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 			do_stats_per_dev = 1;
 			break;
 		case 'q':
-			do_quiet = 1;
+			bconf_be_quiet();
+			do_quiet = !bconf.verbose;
 			break;
 		case 'r':
 			readonly = 1;
@@ -1333,9 +1347,9 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 	}
 
 	if (!n_start && !n_resume) {
-		if (!do_quiet)
-			printf("scrub: nothing to resume for %s, fsid %s\n",
-			       path, fsid);
+		pr_verbose(MUST_LOG,
+			   "scrub: nothing to resume for %s, fsid %s\n",
+			   path, fsid);
 		nothing_to_resume = 1;
 		goto out;
 	}
@@ -1406,10 +1420,10 @@ static int scrub_start(const struct cmd_struct *cmd, int argc, char **argv,
 		if (pid) {
 			int stat;
 			scrub_handle_sigint_parent();
-			if (!do_quiet)
-				printf("scrub %s on %s, fsid %s (pid=%d)\n",
-				       n_start ? "started" : "resumed",
-				       path, fsid, pid);
+			pr_verbose(MUST_LOG,
+				   "scrub %s on %s, fsid %s (pid=%d)\n",
+				   n_start ? "started" : "resumed",
+				   path, fsid, pid);
 			if (!do_wait) {
 				err = 0;
 				goto out;
@@ -1614,6 +1628,9 @@ static const char * const cmd_scrub_start_usage[] = {
 	"-n     set ioprio classdata (see ionice(1) manpage)",
 	"-f     force starting new scrub even if a scrub is already running",
 	"       this is useful when scrub stats record file is damaged",
+	"-q     deprecated, alias for global -q option",
+	HELPINFO_INSERT_GLOBALS,
+	HELPINFO_INSERT_QUIET,
 	NULL
 };
 
@@ -1626,6 +1643,8 @@ static DEFINE_SIMPLE_COMMAND(scrub_start, "start");
 static const char * const cmd_scrub_cancel_usage[] = {
 	"btrfs scrub cancel <path>|<device>",
 	"Cancel a running scrub",
+	HELPINFO_INSERT_GLOBALS,
+	HELPINFO_INSERT_QUIET,
 	NULL
 };
 
@@ -1662,7 +1681,7 @@ static int cmd_scrub_cancel(const struct cmd_struct *cmd, int argc, char **argv)
 	}
 
 	ret = 0;
-	printf("scrub cancelled\n");
+	pr_verbose(MUST_LOG, "scrub cancelled\n");
 
 out:
 	close_file_or_dir(fdmnt, dirstream);
@@ -1676,11 +1695,13 @@ static const char * const cmd_scrub_resume_usage[] = {
 	"",
 	"-B     do not background",
 	"-d     stats per device (-B only)",
-	"-q     be quiet",
 	"-r     read only mode",
 	"-R     raw print mode, print full data instead of summary",
 	"-c     set ioprio class (see ionice(1) manpage)",
 	"-n     set ioprio classdata (see ionice(1) manpage)",
+	"-q     deprecated, alias for global -q option",
+	HELPINFO_INSERT_GLOBALS,
+	HELPINFO_INSERT_QUIET,
 	NULL
 };
 
@@ -1694,8 +1715,9 @@ static const char * const cmd_scrub_status_usage[] = {
 	"btrfs scrub status [-dR] <path>|<device>",
 	"Show status of running or finished scrub",
 	"",
-	"-d     stats per device",
-	"-R     print raw stats",
+	"-d                 stats per device",
+	"-R                 print raw stats",
+	HELPINFO_UNITS_LONG,
 	NULL
 };
 
@@ -1723,6 +1745,9 @@ static int cmd_scrub_status(const struct cmd_struct *cmd, int argc, char **argv)
 	int err = 0;
 	DIR *dirstream = NULL;
 
+	unit_mode = get_unit_mode_from_arg(&argc, argv, 0);
+
+	optind = 0;
 	while ((c = getopt(argc, argv, "dR")) != -1) {
 		switch (c) {
 		case 'd':
