@@ -17,8 +17,9 @@
 #include "kerncompat.h"
 #include <sys/utsname.h>
 #include <linux/version.h>
+#include <unistd.h>
 #include "common/fsfeatures.h"
-#include "ctree.h"
+#include "kernel-shared/ctree.h"
 #include "common/utils.h"
 
 /*
@@ -107,6 +108,12 @@ static const struct btrfs_feature runtime_features[] = {
 	{ "quota", BTRFS_RUNTIME_FEATURE_QUOTA, NULL,
 		VERSION_TO_STRING2(3, 4), NULL, 0, NULL, 0,
 		"quota support (qgroups)" },
+	{ "free-space-tree", BTRFS_RUNTIME_FEATURE_FREE_SPACE_TREE,
+		"free_space_tree",
+		VERSION_TO_STRING2(4, 5),
+		VERSION_TO_STRING2(4, 9),
+		NULL, 0,
+		"free space tree (space_cache=v2)" },
 	/* Keep this one last */
 	{ "list-all", BTRFS_FEATURE_LIST_ALL, NULL }
 };
@@ -320,6 +327,25 @@ u32 get_running_kernel_version(void)
 
 	return version;
 }
+int btrfs_check_sectorsize(u32 sectorsize)
+{
+	u32 page_size = (u32)sysconf(_SC_PAGESIZE);
+
+	if (!is_power_of_2(sectorsize)) {
+		error("invalid sectorsize %u, must be power of 2", sectorsize);
+		return -EINVAL;
+	}
+	if (sectorsize < SZ_4K || sectorsize > SZ_64K) {
+		error("invalid sectorsize %u, expected range is [4K, 64K]",
+		      sectorsize);
+		return -EINVAL;
+	}
+	if (page_size != sectorsize)
+		warning(
+"the filesystem may not be mountable, sectorsize %u doesn't match page size %u",
+			sectorsize, page_size);
+	return 0;
+}
 
 int btrfs_check_nodesize(u32 nodesize, u32 sectorsize, u64 features)
 {
