@@ -922,9 +922,8 @@ int BOX_MAIN(mkfs)(int argc, char **argv)
 	u64 dev_block_count = 0;
 	u64 metadata_profile = 0;
 	u64 data_profile = 0;
-	u32 nodesize = max_t(u32, sysconf(_SC_PAGESIZE),
-			BTRFS_MKFS_DEFAULT_NODE_SIZE);
-	u32 sectorsize = 4096;
+	u32 nodesize = 0;
+	u32 sectorsize = 0;
 	u32 stripesize = 4096;
 	int zero_end = 1;
 	int fd = -1;
@@ -1000,7 +999,7 @@ int BOX_MAIN(mkfs)(int argc, char **argv)
 				warning("--leafsize is deprecated, use --nodesize");
 				/* fall through */
 			case 'n':
-				nodesize = parse_size(optarg);
+				nodesize = parse_size_from_string(optarg);
 				nodesize_forced = 1;
 				break;
 			case 'L':
@@ -1051,10 +1050,10 @@ int BOX_MAIN(mkfs)(int argc, char **argv)
 				break;
 				}
 			case 's':
-				sectorsize = parse_size(optarg);
+				sectorsize = parse_size_from_string(optarg);
 				break;
 			case 'b':
-				block_count = parse_size(optarg);
+				block_count = parse_size_from_string(optarg);
 				zero_end = 0;
 				break;
 			case 'V':
@@ -1092,7 +1091,14 @@ int BOX_MAIN(mkfs)(int argc, char **argv)
 		printf("See %s for more information.\n\n", PACKAGE_URL);
 	}
 
-	sectorsize = max(sectorsize, (u32)sysconf(_SC_PAGESIZE));
+	if (!sectorsize)
+		sectorsize = (u32)sysconf(_SC_PAGESIZE);
+	if (btrfs_check_sectorsize(sectorsize))
+		goto error;
+
+	if (!nodesize)
+		nodesize = max_t(u32, sectorsize, BTRFS_MKFS_DEFAULT_NODE_SIZE);
+
 	stripesize = sectorsize;
 	saved_optind = optind;
 	dev_cnt = argc - optind;
