@@ -7,7 +7,7 @@ if [ -z "$TOP" ]; then
 	TOP=$(readlink -f "$SCRIPT_DIR/../")
 	if [ -f "$TOP/configure.ac" ]; then
 		# inside git
-		TEST_TOP="$TOP/tests/"
+		TEST_TOP="$TOP/tests"
 		INTERNAL_BIN="$TOP"
 	else
 		# external, defaults to system binaries
@@ -21,8 +21,7 @@ else
 	INTERNAL_BIN="$TEST_TOP"
 fi
 if ! [ -x "$TOP/btrfs" ]; then
-	echo "ERROR: cannot execute btrfs from TOP=$TOP"
-	exit 1
+	echo "WARNING: cannot find btrfs in TOP=$TOP"
 fi
 TEST_DEV=${TEST_DEV:-}
 RESULTS="$TEST_TOP/cli-tests-results.txt"
@@ -36,6 +35,7 @@ if [ "$BUILD_VERBOSE" = 1 ]; then
 	verbose=-print
 fi
 
+[ "$BUILD_VERBOSE" = 1 ] && echo "Umount $TEST_MNT"
 $SUDO_HELPER umount -R "$TEST_MNT" &>/dev/null
 
 if ! cd "$TEST_TOP"; then
@@ -43,7 +43,19 @@ if ! cd "$TEST_TOP"; then
 	exit 1
 fi
 
+[ "$BUILD_VERBOSE" = 1 ] && echo "Delete temporary fsck images $TEST_MNT"
 find fsck-tests -type f -name '*.restored' $verbose -delete
 
+for dev in $(losetup --noheadings --output NAME,BACK-FILE | grep "$SCRIPT_DIR"); do
+	# Accept only /dev/loop0
+	# And skip $SCRIPT_DIR/cli-tests/001-test/img1
+	if [[ $dev =~ ^/dev/loop ]]; then
+		lfile=$(losetup --noheadings --output BACK-FILE "$dev")
+		[ "$BUILD_VERBOSE"  = 1 ] &&
+			echo "Detach loop device/file $dev ($lfile)"
+		$SUDO_HELPER losetup --detach "$dev"
+	fi
+done
+
 # do not remove, the file could have special permissions set
 echo -n > test.img
