@@ -8,7 +8,7 @@ if [ -z "$TOP" ]; then
 	TOP=$(readlink -f "$SCRIPT_DIR/../")
 	if [ -f "$TOP/configure.ac" ]; then
 		# inside git
-		TEST_TOP="$TOP/tests/"
+		TEST_TOP="$TOP/tests"
 		INTERNAL_BIN="$TOP"
 	else
 		# external, defaults to system binaries
@@ -52,7 +52,7 @@ do
 	name=$(basename "$i")
 	cd "$i"
 	if [ -x test.sh ]; then
-		echo "=== Entering $i" >> "$RESULTS"
+		echo "=== START TEST $i" >> "$RESULTS"
 		echo "    [TEST/cli]   $name"
 		./test.sh
 		if [ $? -ne 0 ]; then
