@@ -18,15 +18,15 @@ cp partition-1g-1g img
 run_check truncate -s2g img
 
 loopdev=$(run_check_stdout $SUDO_HELPER losetup --partscan --find --show img)
-base=$(basename $loopdev)
+base=$(basename "$loopdev")
 
 # expect partitions named like loop0p1 etc
-for looppart in $(ls /dev/$base?*); do
-	run_check $SUDO_HELPER $TOP/mkfs.btrfs -f $looppart
-	run_check $SUDO_HELPER $TOP/btrfs inspect-internal dump-super $looppart
+for looppart in $(ls /dev/"$base"?*); do
+	run_check $SUDO_HELPER "$TOP/mkfs.btrfs" -f "$looppart"
+	run_check $SUDO_HELPER "$TOP/btrfs" inspect-internal dump-super "$looppart"
 done
 
 # cleanup
-run_check $SUDO_HELPER losetup -d $loopdev
+run_check $SUDO_HELPER losetup -d "$loopdev"
 run_check truncate -s0 img
 rm img
