@@ -15,7 +15,7 @@ prepare_test_dev "$fs_size"
 
 # No shrink case
 
-run_check "$TOP/mkfs.btrfs" -f --rootdir "$tmp" "$TEST_DEV"
+run_check_mkfs_test_dev --rootdir "$tmp"
 run_check_mount_test_dev
 
 # We should be able to write at least half of the fs size data since the fs is
@@ -27,7 +27,7 @@ run_check_umount_test_dev
 
 # Shrink case
 
-run_check "$TOP/mkfs.btrfs" -f --rootdir "$tmp" --shrink "$TEST_DEV"
+run_check_mkfs_test_dev --rootdir "$tmp" --shrink
 run_check_mount_test_dev
 
 run_mustfail "mkfs.btrfs for shrink rootdir" \
